Bioinorganic chemistry - Wikipedia

Jump to content

# Bioinorganic chemistry

29 languages

- العربية
- Български
- Català
- Deutsch
- Eesti
- Español
- فارسی
- Français
- 한국어
- Bahasa Indonesia
- Italiano
- ქართული
- Magyar
- Nederlands
- 日本語
- Polski
- Português
- Română
- Русский
- Simple English
- Slovenčina
- Српски / srpski
- Srpskohrvatski / српскохрватски
- தமிழ்
- ไทย
- Türkçe
- Українська
- 粵語
- 中文

Edit links
From Wikipedia, the free encyclopedia
Study of the role of metals in biology

Bioinorganic chemistry is a field that examines the role of metals in biology. Bioinorganic chemistry includes the study of both natural phenomena such as the behavior of metalloproteins as well as artificially introduced metals, including those that are non-essential, in medicine and toxicology. Many biological processes such as respiration depend upon molecules that fall within the realm of inorganic chemistry. The discipline also includes the study of inorganic models or mimics that imitate the behaviour of metalloproteins.[1]

As a mix of biochemistry and inorganic chemistry, bioinorganic chemistry is important in elucidating the implications of electron-transfer proteins, substrate bindings and activation, atom and group transfer chemistry as well as metal properties in biological chemistry. The successful development of truly interdisciplinary work is necessary to advance bioinorganic chemistry.[2]

## Composition of living organisms

[edit]

About 99% of mammals' mass are the elements carbon, nitrogen, calcium, sodium, chlorine, potassium, hydrogen, phosphorus, oxygen and sulfur.[3] The organic compounds (proteins, lipids and carbohydrates) contain the majority of the carbon and nitrogen and most of the oxygen and hydrogen is present as water.[3] The entire collection of metal-containing biomolecules in a cell is called the metallome.

## History

[edit]

Paul Ehrlich used organoarsenic ("arsenicals") for the treatment of syphilis, demonstrating the relevance of metals, or at least metalloids, to medicine, that blossomed with Rosenberg's discovery of the anti-cancer activity of cisplatin (cis-PtCl2(NH3)2). The first protein ever crystallized (see James B. Sumner) was urease, later shown to contain nickel at its active site. Vitamin B12, the cure for pernicious anemia was shown crystallographically by Dorothy Crowfoot Hodgkin to consist of a cobalt in a corrin macrocycle.

## Themes in bioinorganic chemistry

[edit]

Several distinct systems are of identifiable in bioinorganic chemistry. Major areas include:

### Metal ion transport and storage

[edit]

A diverse collection of transporters (e.g. the ion pump NaKATPase), vacuoles, storage proteins (e.g. ferritin), and small molecules (e.g. siderophores) are employed to control metal ions concentration and bio-availability in living organisms. Crucially, many essential metals are not readily accessible to downstream proteins owing to low solubility in aqueous solutions or scarcity in the cellular environment. Organisms have developed a number of strategies for collecting and transporting such elements while limiting their cytotoxicity.

### Enzymology

[edit]

Many reactions in life sciences involve water and metal ions are often at the catalytic centers (active sites) for these enzymes, i.e. these are metalloproteins. Often the reacting water is a ligand (see metal aquo complex). Examples of hydrolase enzymes are carbonic anhydrase, metallophosphatases, and metalloproteinases. Bioinorganic chemists seek to understand and replicate the function of these metalloproteins.

Metal-containing electron transfer proteins are also common. They can be organized into three major classes: iron–sulfur proteins (such as rubredoxins, ferredoxins, and Rieske proteins), blue copper proteins, and cytochromes. These electron transport proteins are complementary to the non-metal electron transporters nicotinamide adenine dinucleotide (NAD) and flavin adenine dinucleotide (FAD). The nitrogen cycle make extensive use of metals for the redox interconversions.

4Fe-4S clusters serve as electron-relays in proteins.

### Toxicity

[edit]

Several metal ions are toxic to humans and other animals. The bioinorganic chemistry of lead in the context of its toxicity has been reviewed.[4]

### Oxygen transport and activation proteins

[edit]

Aerobic life make extensive use of metals such as iron, copper, and manganese. Heme is utilized by red blood cells in the form of hemoglobin for oxygen transport and is perhaps the most recognized metal system in biology. Other oxygen transport systems include myoglobin, hemocyanin, and hemerythrin. Oxidases and oxygenases are metal systems found throughout nature that take advantage of oxygen to carry out important reactions such as energy generation in cytochrome c oxidase or small molecule oxidation in cytochrome P450 oxidases or methane monooxygenase. Some metalloproteins are designed to protect a biological system from the potentially harmful effects of oxygen and other reactive oxygen-containing molecules such as hydrogen peroxide. These systems include peroxidases, catalases, and superoxide dismutases. A complementary metalloprotein to those that react with oxygen is the oxygen evolving complex present in plants. This system is part of the complex protein machinery that produces oxygen as plants perform photosynthesis.

Myoglobin is a prominent subject in bioinorganic chemistry, with particular attention to the iron-heme complex that is anchored to the protein.

### Bioorganometallic chemistry

[edit]

Bioorganometallic systems feature metal-carbon bonds as structural elements or as intermediates. Bioorganometallic enzymes and proteins include the hydrogenases, FeMoco in nitrogenase, and methylcobalamin. These naturally occurring organometallic compounds. This area is more focused on the utilization of metals by unicellular organisms. Bioorganometallic compounds are significant in environmental chemistry.[5]

Structure of FeMoco, the catalytic center of nitrogenase.

### Metals in medicine

[edit]

A number of drugs contain metals. This theme relies on the study of the design and mechanism of action of metal-containing pharmaceuticals, and compounds that interact with endogenous metal ions in enzyme active sites. The most widely used anti-cancer drug is cisplatin. MRI contrast agent commonly contain gadolinium. Lithium carbonate has been used to treat the manic phase of bipolar disorder. Gold antiarthritic drugs, e.g. auranofin have been commercialized. Carbon monoxide-releasing molecules are metal complexes have been developed to suppress inflammation by releasing small amounts of carbon monoxide. The cardiovascular and neuronal importance of nitric oxide has been examined, including the enzyme nitric oxide synthase. (See also: nitrogen assimilation.) Besides, metallic transition complexes based on triazolopyrimidines have been tested against several parasite strains.[6]

### Environmental chemistry

[edit]

Environmental chemistry traditionally emphasizes the interaction of heavy metals with organisms. Methylmercury has caused major disaster called Minamata disease. Arsenic poisoning is a widespread problem owing largely to arsenic contamination of groundwater, which affects many millions of people in developing countries. The metabolism of mercury- and arsenic-containing compounds involves cobalamin-based enzymes.

### Biomineralization

[edit]

Biomineralization is the process by which living organisms produce minerals, often to harden or stiffen existing tissues. Such tissues are called mineralized tissues.[7][8][9] Examples include silicates in algae and diatoms, carbonates in invertebrates, and calcium phosphates and carbonates in vertebrates. Other examples include copper, iron and gold deposits involving bacteria. Biologically-formed minerals often have special uses such as magnetic sensors in magnetotactic bacteria (Fe3O4), gravity sensing devices (CaCO3, CaSO4, BaSO4) and iron storage and mobilization (Fe2O3•H2O in the protein ferritin). Because extracellular[10] iron is strongly involved in inducing calcification,[11][12] its control is essential in developing shells; the protein ferritin plays an important role in controlling the distribution of iron.[13]

## Types of inorganic substances in biology

[edit]

### Alkali and alkaline earth metals

[edit]
Like many antibiotics, monensin-A is an ionophore that tightly bind Na+ (shown in yellow).[14]

The abundant inorganic elements act as ionic electrolytes. The most important ions are sodium, potassium, calcium, magnesium, chloride, phosphate, and bicarbonate. The maintenance of precise gradients across cell membranes maintains osmotic pressure and pH.[15] Ions are also critical for nerves and muscles, as action potentials in these tissues are produced by the exchange of electrolytes between the extracellular fluid and the cytosol.[16] Electrolytes enter and leave cells through proteins in the cell membrane called ion channels. For example, muscle contraction depends upon the movement of calcium, sodium and potassium through ion channels in the cell membrane and T-tubules.[17]

### Transition metals

[edit]

The transition metals are usually present as trace elements in organisms, with zinc and iron being most abundant.[18][19][20] These metals are used as protein cofactors and signalling molecules. Many are essential for the activity of enzymes such as catalase and oxygen-carrier proteins such as hemoglobin.[21] These cofactors are tightly to a specific protein; although enzyme cofactors can be modified during catalysis, cofactors always return to their original state after catalysis has taken place. The metal micronutrients are taken up into organisms by specific transporters and bound to storage proteins such as ferritin or metallothionein when not being used.[22][23] Cobalt is essential for the functioning of vitamin B12.[24]

### Main group compounds

[edit]

Many other elements aside from metals are bio-active. Sulfur and phosphorus are required for all life. Phosphorus almost exclusively exists as phosphate and its various esters. Sulfur exists in a variety of oxidation states, ranging from sulfate (SO2−
4) down to sulfide (S2−). Selenium is a trace element involved in proteins that are antioxidants. Cadmium is important because of its toxicity.[25]

## See also

[edit]

- Cofactor
- Iron metabolism
- Physiology

## References

[edit]

1. ^ Stephen J. Lippard, Jeremy M. Berg, Principles of Bioinorganic Chemistry, University Science Books, 1994,
   ISBN 978-0-935702-72-9
2. ^ Gumerova, Nadiia I.; Rompel, Annette (2021-03-31). "Interweaving Disciplines to Advance Chemistry: Applying Polyoxometalates in Biology". Inorganic Chemistry. 60 (9): 6109–6114. doi:10.1021/acs.inorgchem.1c00125. ISSN 0020-1669. PMC 8154434. PMID 33787237.
3. ^ a b Heymsfield S, Waki M, Kehayias J, Lichtman S, Dilmanian F, Kamen Y, Wang J, Pierson R (1991). "Chemical and elemental analysis of humans in vivo using improved body composition models". American Journal of Physiology. 261 (2 Pt 1): E190–8. doi:10.1152/ajpendo.1991.261.2.E190. PMID 1872381.
4. ^ Maret, Wolfgang (2017). "Chapter 1. The Bioinorganic Chemistry of Lead in the Context of its Toxicity". In Astrid, S.; Helmut, S.; Sigel, R. K. O. (eds.). Lead: Its Effects on Environment and Health. Metal Ions in Life Sciences. Vol. 17. de Gruyter. pp. 1–20. doi:10.1515/9783110434330-001. ISBN 978-3-11-043433-0. PMID 28731294.
5. ^ Sigel, A.; Sigel, H.; Sigel, R.K.O., eds. (2010). Organometallics in Environment and Toxicology. Metal Ions in Life Sciences. Vol. 7. Cambridge: RSC publishing. ISBN 978-1-84755-177-1.
6. ^ Méndez-Arriaga JM, Oyarzabal I, et al. (March 2018). "In vitro leishmanicidal and trypanocidal evaluation and magnetic properties of 7-amino-1,2,4-triazolo[1,5-a]pyrimidine Cu(II) complexes". Journal of Inorganic Biochemistry. 180: 26–32. doi:10.1016/j.jinorgbio.2017.11.027. PMID 29227923.
7. ^ Astrid Sigel, Helmut Sigel and Roland K.O. Sigel, ed. (2008). Biomineralization: From Nature to Application. Metal Ions in Life Sciences. Vol. 4. Wiley. ISBN 978-0-470-03525-2.
8. ^ Weiner, Stephen; Lowenstam, Heinz A. (1989). On biomineralization. Oxford [Oxfordshire]: Oxford University Press. ISBN 978-0-19-504977-0.
9. ^ Jean-Pierre Cuif; Yannicke Dauphin; James E. Sorauf (2011). Biominerals and fossils through time. Cambridge. ISBN 978-0-521-87473-1.
10. ^ Gabbiani G, Tuchweber B (1963). "The role of iron in the mechanism of experimental calcification". J Histochem Cytochem. 11 (6): 799–803. doi:10.1177/11.6.799.
11. ^ Schulz, K.; Zondervan, I.; Gerringa, L.; Timmermans, K.; Veldhuis, M.; Riebesell, U. (2004). "Effect of trace metal availability on coccolithophorid calcification" (PDF). Nature. 430 (7000): 673–676. Bibcode:2004Natur.430..673S. doi:10.1038/nature02631. PMID 15295599.
12. ^ Anghileri, L. J.; Maincent, P.; Cordova-Martinez, A. (1993). "On the mechanism of soft tissue calcification induced by complexed iron". Experimental and Toxicologic Pathology. 45 (5–6): 365–368. Bibcode:1993EToxP..45..365A. doi:10.1016/S0940-2993(11)80429-X. PMID 8312724.
13. ^ Jackson, D. J.; Wörheide, G.; Degnan, B. M. (2007). "Dynamic expression of ancient and novel molluscan shell genes during ecological transitions". BMC Evolutionary Biology. 7 (1) 160. Bibcode:2007BMCEE...7..160J. doi:10.1186/1471-2148-7-160. PMC 2034539. PMID 17845714.
14. ^ Greenwood, Norman N.; Earnshaw, Alan (1997). Chemistry of the Elements (2nd ed.). Butterworth-Heinemann. doi:10.1016/C2009-0-30414-6. ISBN 978-0-08-037941-8.
15. ^ Sychrová H (2004). "Yeast as a model organism to study transport and homeostasis of alkali metal cations" (PDF). Physiol Res. 53 (Suppl 1): S91–8. doi:10.33549/physiolres.930000.53.S91. PMID 15119939.
16. ^ Levitan I (1988). "Modulation of ion channels in neurons and other cells". Annu Rev Neurosci. 11: 119–36. doi:10.1146/annurev.ne.11.030188.001003. PMID 2452594.
17. ^ Dulhunty A (2006). "Excitation-contraction coupling from the 1950s into the new millennium". Clin Exp Pharmacol Physiol. 33 (9): 763–72. doi:10.1111/j.1440-1681.2006.04441.x. PMID 16922804.
18. ^ Dlouhy, Adrienne C.; Outten, Caryn E. (2013). "The Iron Metallome in Eukaryotic Organisms". In Banci, Lucia (ed.). Metallomics and the Cell. Metal Ions in Life Sciences. Vol. 12. Springer. pp. 241–78. doi:10.1007/978-94-007-5561-1_8. ISBN 978-94-007-5560-4. PMC 3924584. PMID 23595675. electronic-book ISBN 978-94-007-5561-1 ISSN 1559-0836 electronic-ISSN 1868-0402
19. ^ Mahan D, Shields R (1998). "Macro- and micromineral composition of pigs from birth to 145 kilograms of body weight". J Anim Sci. 76 (2): 506–12. doi:10.2527/1998.762506x. PMID 9498359. Archived from the original on 2011-04-30.
20. ^ Husted S, Mikkelsen B, Jensen J, Nielsen N (2004). "Elemental fingerprint analysis of barley (Hordeum vulgare) using inductively coupled plasma mass spectrometry, isotope-ratio mass spectrometry, and multivariate statistics". Anal Bioanal Chem. 378 (1): 171–82. doi:10.1007/s00216-003-2219-0. PMID 14551660.
21. ^ Finney L, O'Halloran T (2003). "Transition metal speciation in the cell: insights from the chemistry of metal ion receptors". Science. 300 (5621): 931–6. Bibcode:2003Sci...300..931F. doi:10.1126/science.1085049. PMID 12738850. S2CID 14863354.
22. ^ Cousins R, Liuzzi J, Lichten L (2006). "Mammalian zinc transport, trafficking, and signals". J Biol Chem. 281 (34): 24085–9. doi:10.1074/jbc.R600011200. PMID 16793761.
23. ^ Dunn L, Rahmanto Y, Richardson D (2007). "Iron uptake and metabolism in the new millennium". Trends Cell Biol. 17 (2): 93–100. doi:10.1016/j.tcb.2006.12.003. PMID 17194590.
24. ^ Cracan, Valentin; Banerjee, Ruma (2013). "Cobalt and Corrinoid Transport and Biochemistry". In Banci, Lucia (ed.). Metallomics and the Cell. Metal Ions in Life Sciences. Vol. 12. Springer. pp. 333–74. doi:10.1007/978-94-007-5561-1_10. ISBN 978-94-007-5560-4. PMID 23595677. electronic-book ISBN 978-94-007-5561-1 ISSN 1559-0836 electronic-ISSN 1868-0402
25. ^ Maret, Wolfgang; Moulis, Jean-Marc (2013). "Chapter 1. The Bioinorganic Chemistry of Cadmium in the Context of its Toxicity". In Astrid Sigel, Helmut Sigel and Roland K. O. Sigel (ed.). Cadmium: From Toxicology to Essentiality. Metal Ions in Life Sciences. Vol. 11. Springer. pp. 1–30.

## Literature

[edit]

- Heinz-Bernhard Kraatz (editor), Nils Metzler-Nolte (editor), Concepts and Models in Bioinorganic Chemistry, John Wiley and Sons, 2006, ISBN 978-3-527-31305-1
- Ivano Bertini, Harry B. Gray, Edward I. Stiefel, Joan Selverstone Valentine, Biological Inorganic Chemistry, University Science Books, 2007, ISBN 978-1-891389-43-6
- Wolfgang Kaim, Brigitte Schwederski "Bioinorganic Chemistry: Inorganic Elements in the Chemistry of Life." John Wiley and Sons, 1994, ISBN 978-0-471-94369-3
- Rosette M. Roat-Malone, Bioinorganic Chemistry : A Short Course, Wiley-Interscience, 2002, ISBN 978-0-471-15976-6
- J.J.R. Fraústo da Silva and R.J.P. Williams, The biological chemistry of the elements: The inorganic chemistry of life, 2nd Edition, Oxford University Press, 2001, ISBN 978-0-19-850848-9
- Lawrence Que, Jr., ed., Physical Methods in Bioinorganic Chemistry, University Science Books, 2000, ISBN 978-1-891389-02-3

## External links

[edit]

- The Society of Biological Inorganic Chemistry (SBIC)'s home page
- The French Bioinorganic Chemistry Society
- Glossary of Terms in Bioinorganic Chemistry
- Metal Coordination Groups in Proteins by Marjorie Harding
- European Bioinformatics Institute
- MetalPDB: A database of metal sites in biomolecular structures Archived 2015-09-15 at the Wayback Machine

Retrieved from "https://en.wikipedia.org/w/index.php?title=Bioinorganic_chemistry&oldid=1315618540"
Categories:

- Bioinorganic chemistry
- Biochemistry
- Inorganic chemistry
- Medicinal inorganic chemistry

Hidden categories:

- Articles with short description
- Short description is different from Wikidata
- Webarchive template wayback links

Bioinorganic chemistry
Add topic